#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MHALF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MHALF_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mhalf.hpp>

#endif
